==> commerce_gc_client-2.0.0.tar.gz: commerce_gc_client/src/Event/WebhookEvent.php <==
<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Component\EventDispatcher\Event;

/**
 * Event that is fired after a payment has been created at GoCardless.
 */
class WebhookEvent extends Event {

  /**
   * The webhook event provided by GoCardless.
   *
   * @var array
   */
  protected $webhook_event;

  /**
   * A resource relating to a webhook event from GoCardless.
   *
   * Applies to 'payments' type events only.
   *
   * @var array
   */
  protected $resource;

  /**
   * The Commerce order ID that the webhook event relates to.
   *
   * @var integer
   */
  protected $order_id;

  /**
   * Constructs the object.
   *
   * @param array $event
   *   The webhook event provided by GoCardless.
   * @param array $resource
   *   A resource relating to a webhook event from GoCardless.
   * @param integer $order_id
   *   The Commerce order ID that the webhook event relates to.
   */
  public function __construct($webhook_event, $resource, $order_id) {
    $this->webhook_event = $webhook_event;
    $this->resource = $resource;
    $this->order_id = $order_id;
  }

  /**
   * Gets the webhook event.
   *
   * @return array
   *   The webhook event provided by GoCardless.
   */
  public function getWebhookEvent() {
    return $this->webhook_event;
  }

  /**
   * Gets the resource.
   *
   * @return array
   *   A resource relating to a webhook event from GoCardless.
   */
  public function getResource() {
    return $this->resource;
  }

  /**
   * Gets the order ID.
   *
   * @return integer
   *   The Commerce order ID that the webhook event relates to.
   */
  public function getOrderId() {
    return $this->order_id;
  }
}

==> commerce_gc_client-2.0.6.tar.gz: commerce_gc_client/src/Event/WebhookEvent.php <==
<?php

namespace Drupal\commerce_gc_client\Event;

use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event that is fired after a webhook is received from GoCardless.
 */
class WebhookEvent extends Event {

  /**
   * The webhook event provided by GoCardless.
   *
   * @var array
   */
  protected $webhookEvent;

  /**
   * A resource relating to a webhook event from GoCardless.
   *
   * Applies to 'payments' type events only.
   *
   * @var array
   */
  protected $resource;

  /**
   * The Commerce order ID that the webhook event relates to.
   *
   * @var int
   */
  protected $orderId;

  /**
   * Constructs the object.
   *
   * @param array $webhookEvent
   *   The webhook event provided by GoCardless.
   * @param array|null $resource
   *   Array containing a "resource" relating to a GoCardless Payments webhook
   *   event, or NULL for other types of event.
   * @param int $orderId
   *   The Commerce order ID that the webhook event relates to.
   */
  public function __construct(array $webhookEvent, $resource, $orderId) {
    $this->webhookEvent = $webhookEvent;
    $this->resource = $resource;
    $this->orderId = $orderId;
  }

  /**
   * Gets the webhook event.
   *
   * @return array
   *   The webhook event provided by GoCardless.
   */
  public function getWebhookEvent() {
    return $this->webhookEvent;
  }

  /**
   * Gets the resource.
   *
   * @return array
   *   A resource relating to a webhook event from GoCardless.
   */
  public function getResource() {
    return $this->resource;
  }

  /**
   * Gets the order ID.
   *
   * @return int
   *   The Commerce order ID that the webhook event relates to.
   */
  public function getOrderId() {
    return $this->orderId;
  }

}
